@@ -145,6 +145,33 @@ class CroniterTest(base.TestCase):
         self.assertEqual(n3.day, 3)
         self.assertEqual(n3.year, 2010)
 
+    def testNthWeekDay(self):
+        base = datetime(2010, 2, 25)
+        itr = croniter('0 0 * * sat#1', base)
+        n1 = itr.get_next(datetime)
+        self.assertEqual(n1.isoweekday(), 6)
+        self.assertEqual(n1.day, 6)
+        self.assertEqual(n1.month, 3)
+        n2 = itr.get_next(datetime)
+        self.assertEqual(n2.isoweekday(), 6)
+        self.assertEqual(n2.day, 3)
+        self.assertEqual(n2.month, 4)
+
+        base = datetime(2010, 1, 25)
+        itr = croniter('0 0 * * wed#5', base)
+        n1 = itr.get_next(datetime)
+        self.assertEqual(n1.month, 3)
+        self.assertEqual(n1.day, 31)
+        self.assertEqual(n1.year, 2010)
+        n2 = itr.get_next(datetime)
+        self.assertEqual(n2.month, 6)
+        self.assertEqual(n2.day, 30)
+        self.assertEqual(n2.year, 2010)
+        n3 = itr.get_next(datetime)
+        self.assertEqual(n3.month, 9)
+        self.assertEqual(n3.day, 29)
+        self.assertEqual(n3.year, 2010)
+
     def testWeekDayDayAnd(self):
         base = datetime(2010, 1, 25)
         itr = croniter('0 0 1 * mon', base, day_or=False)
@@ -323,6 +350,30 @@ class CroniterTest(base.TestCase):
         self.assertEqual(prev3.hour, 0)
         self.assertEqual(prev3.minute, 0)
 
+    def testPrevNthWeekDay(self):
+        base = datetime(2010, 8, 25, 15, 56)
+        itr = croniter('0 0 * * sat#1,sun#2', base)
+        prev1 = itr.get_prev(datetime)
+        self.assertEqual(prev1.year, base.year)
+        self.assertEqual(prev1.month, base.month)
+        self.assertEqual(prev1.day, 8)
+        self.assertEqual(prev1.hour, 0)
+        self.assertEqual(prev1.minute, 0)
+
+        prev2 = itr.get_prev(datetime)
+        self.assertEqual(prev2.year, base.year)
+        self.assertEqual(prev2.month, base.month)
+        self.assertEqual(prev2.day, 7)
+        self.assertEqual(prev2.hour, 0)
+        self.assertEqual(prev2.minute, 0)
+
+        prev3 = itr.get_prev(datetime)
+        self.assertEqual(prev3.year, base.year)
+        self.assertEqual(prev3.month, 7)
+        self.assertEqual(prev3.day, 11)
+        self.assertEqual(prev3.hour, 0)
+        self.assertEqual(prev3.minute, 0)
+
     def testPrevWeekDay2(self):
         base = datetime(2010, 8, 25, 15, 56)
         itr = croniter('10 0 * * 0', base)
